===========
algotik-tse
===========


.. image:: https://img.shields.io/pypi/v/algotik_tse.svg
        :target: https://pypi.python.org/pypi/algotik_tse

.. image:: https://img.shields.io/travis/mohsenalipour/algotik_tse.svg
        :target: https://travis-ci.com/mohsenalipour/algotik_tse

.. image:: https://readthedocs.org/projects/algotik-tse/badge/?version=latest
        :target: https://algotik-tse.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/mohsenalipour/algotik_tse/shield.svg
     :target: https://pyup.io/repos/github/mohsenalipour/algotik_tse/
     :alt: Updates



Get all data from TSETMC.com (Tehran Bourse).


* Free software: GNU General Public License v3
* Documentation: https://algotik-tse.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
